# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [v0.1.3](https://github.com/jackton1/django-clone/releases/tag/v0.1.3) ([compare](https://github.com/jackton1/django-clone/compare/v0.1.2...v0.1.3))

### Documented
- docs: update .all-contributorsrc [skip ci] ([05d17f1](https://github.com/jackton1/django-clone/commit/05d17f195bd7ef282578271bc14bcd97f5ac4a35)).
- docs: update README.md [skip ci] ([72fee8b](https://github.com/jackton1/django-clone/commit/72fee8b9a643a12631db79c2158073d7ea325011)).

### Fixed
- Fix lint errors ([9dab0f7](https://github.com/jackton1/django-clone/commit/9dab0f7c5d7c6105d1552d3130050aa0889f94df)).
- Fixed example documentation. ([b6ceae9](https://github.com/jackton1/django-clone/commit/b6ceae92bae52e7efa49789ffcd1cb7b749a8546)).
- Fixed invalid config. ([d33354b](https://github.com/jackton1/django-clone/commit/d33354ba8f83c5c694f52512db0575ce12d6fa19)).
- Fixed lint errors. ([a72040d](https://github.com/jackton1/django-clone/commit/a72040d601a19e341d39381510c949d2f2316251)).
- Fixed typo ([e2f9643](https://github.com/jackton1/django-clone/commit/e2f9643ffd165adbe98c343293936b879061056d)).

### Removed
- Removed trailing whitespace. ([6933020](https://github.com/jackton1/django-clone/commit/6933020271094b054a9753e64a75d1064bb2fdb7)).
- Removed unused line ([0307889](https://github.com/jackton1/django-clone/commit/0307889c5550b098fa8cf553c91d0a5b3756b1ff)).

### Misc
- "2020-04-16 14:15 - Increased django-clone version: VERSION = (0, 1, 2) to VERSION = (0, 1, 3)" ([5826499](https://github.com/jackton1/django-clone/commit/582649950319c89751212de7a43b3c87cb37d53f)).
- Actually clone many_to_one fields not only transfer related ([85e6941](https://github.com/jackton1/django-clone/commit/85e6941513647f06c694c0490d279f437c39a780)).
- Create FUNDING.yml ([25fd02f](https://github.com/jackton1/django-clone/commit/25fd02f522d1ff80594fa67e02d66e4ac074905c)).
- Reordered badges ([9e5b8d1](https://github.com/jackton1/django-clone/commit/9e5b8d1328dcacdf0746140e0e443435b7aae6d5)).
- Switched to .set ([4aa377a](https://github.com/jackton1/django-clone/commit/4aa377abb21b1f0d3e59b5b028f06b15a7f18eab)).
- Update README.md ([bc00a9a](https://github.com/jackton1/django-clone/commit/bc00a9a1d447894f30c6d140291058688c8b4ee8)).
- Update README.md ([d30b266](https://github.com/jackton1/django-clone/commit/d30b266a37a6d4c798f22baa2bd8ac7005d90758)).
- Update README.md ([cb58857](https://github.com/jackton1/django-clone/commit/cb588571f8337222db8612e2a2de6e44e2fe8eb6)).
- Update README.md ([a0f1e47](https://github.com/jackton1/django-clone/commit/a0f1e47a50c766a666c32737f619d962a52474c6)).
- Update README.md ([eacb836](https://github.com/jackton1/django-clone/commit/eacb8368e089152bc38d2b2b714ea9b7d9b1659b)).
- Update README.md ([ca98fed](https://github.com/jackton1/django-clone/commit/ca98fededac6a03b8115d3420db339f0c89bc648)).
- Update README.md ([02f0155](https://github.com/jackton1/django-clone/commit/02f0155edc8283fee1465ed94a57d3c7a831195e)).
- Update README.md ([d07c230](https://github.com/jackton1/django-clone/commit/d07c230e47a370eccfe86562adf398dbe6e22e87)).
- Update setup.py ([4f99987](https://github.com/jackton1/django-clone/commit/4f99987f69caae0f6aa57b7c770176ee62360466)).
- Update tox.ini ([feb6cd8](https://github.com/jackton1/django-clone/commit/feb6cd875fc249708e82385295b8abc907604f77)).
- Updated .set passing the instance instead of pk. ([0d38e8d](https://github.com/jackton1/django-clone/commit/0d38e8d696bf89746ce599a4cb9fe1aa3219ce0d)).
- Updated the .circle config. ([a2a4dcc](https://github.com/jackton1/django-clone/commit/a2a4dcc57db08e4baf90a263977ecb220eedc5be)).


## [v0.1.2](https://github.com/jackton1/django-clone/releases/tag/v0.1.2) ([compare](https://github.com/jackton1/django-clone/compare/v0.1.1...v0.1.2)) - 2019-12-03

### Fixed
- Fixed flake8 errors. ([ac0c27b](https://github.com/jackton1/django-clone/commit/ac0c27b2a93c10c29b3a32990752d3c544bf9619)).
- Fixed test. ([5b65a84](https://github.com/jackton1/django-clone/commit/5b65a842380d30ec84e4e6d3db882702385bfec8)).

### Removed
- Remove tabs. ([f8c1a46](https://github.com/jackton1/django-clone/commit/f8c1a46e77c5c1ec42f4fc84af6872d2861a8a69)).
- Remove unused code. ([ecfa4b6](https://github.com/jackton1/django-clone/commit/ecfa4b623ed4456cff431095f4b62ec41badb829)).
- Remove unused code. ([dca546c](https://github.com/jackton1/django-clone/commit/dca546c24f41d33ce4860cc5e2b8acae92480323)).
- Remove unused code. ([229eb94](https://github.com/jackton1/django-clone/commit/229eb940021b2bd7553ee6266dffcb17c832b86b)).
- Removed unused line. ([4e1d5d1](https://github.com/jackton1/django-clone/commit/4e1d5d144acccfb8a15a8551ce3902338387467b)).

### Misc
- "2019-12-02 20:19 - Increased django-clone version: VERSION = (0, 1, 1) to VERSION = (0, 1, 2)" ([a2fad40](https://github.com/jackton1/django-clone/commit/a2fad4054fa1f9a6a7abed350d9a33094d7acb33)).
- Upated the config. ([adc31d0](https://github.com/jackton1/django-clone/commit/adc31d076acb4b532e87554d45818a6324c3d937)).
- Updated CHANGELOG.md. ([285fc66](https://github.com/jackton1/django-clone/commit/285fc6639101a54785dcb728cdcfee61c05b4765)).


## [v0.1.1](https://github.com/jackton1/django-clone/releases/tag/v0.1.1) ([compare](https://github.com/jackton1/django-clone/compare/v0.1.0...v0.1.1)) - 2019-12-02

### Added
- Added PyPi badge. ([e0a09e4](https://github.com/jackton1/django-clone/commit/e0a09e4dd084fd7ffe2c95a66aaa1a5b09762d78)).
- Added spec for cloning in parallel. ([bede5de](https://github.com/jackton1/django-clone/commit/bede5de00cd40a610c65d9d8ae19fa270cf8fc41)).

### Fixed
- Fix bug with cloning unique fields and added support for bulk_clone. ([70e76a8](https://github.com/jackton1/django-clone/commit/70e76a81e6497ef52a2d525bc4a5e6a27d5b0e75)).
- Fix typo cloneModelAdmin -> CloneModelAdmin ([b8a29c2](https://github.com/jackton1/django-clone/commit/b8a29c240aba7f7736ef297a69f54eb0a399d1ad)).
- Fixed example. ([1ad41d3](https://github.com/jackton1/django-clone/commit/1ad41d3f2866136a53d4fc0f91ded97ffe5f7f89)).
- Fixed flake8 error. ([b28fb8c](https://github.com/jackton1/django-clone/commit/b28fb8c5f67f1ef9b790fa7f0ac3e9b106544d6f)).
- Fixed indentation. ([75214a5](https://github.com/jackton1/django-clone/commit/75214a5b786a5322b8aa2af59fc95f6d0d10a78c)).
- Fixed lint errors and added support for running autopep8. ([4537a46](https://github.com/jackton1/django-clone/commit/4537a460de92d0ef34c875d37439f79c26a69d36)).
- Fixed test. ([ec39547](https://github.com/jackton1/django-clone/commit/ec395478f1ecfce4a1d1a0afbc8f0299d5f4c6dc)).

### Removed
- Remove .extend. ([3e31e86](https://github.com/jackton1/django-clone/commit/3e31e86ab49d834cc2aad89760fa2a25eff687df)).

### Misc
- "2019-12-02 10:28 - Increased django-clone version: VERSION = (0, 1, 0) to VERSION = (0, 1, 1)" ([c033538](https://github.com/jackton1/django-clone/commit/c033538a1da2500098d509d3f1aac2b4b91c0a67)).
- Cleaned up the sample app. ([4ed3a52](https://github.com/jackton1/django-clone/commit/4ed3a52b0293a0510338c0886693cc6c386bf683)).
- Handle case when value in unquie field has fields max_length ([02d7c48](https://github.com/jackton1/django-clone/commit/02d7c4857301d33066b2a27b041e11089d558c81)).
- Imprvoed docstrings. ([4eec273](https://github.com/jackton1/django-clone/commit/4eec273f6d6c849d4d7d36b78411116f411343d0)).
- Switched to use TransactionManagementError exception. ([fa2d18c](https://github.com/jackton1/django-clone/commit/fa2d18c3873daa2445b760d09351505a96e98f94)).
- Update README.md ([cd4bc76](https://github.com/jackton1/django-clone/commit/cd4bc76fccc39ee51b496dec65a447932fe5f285)).
- Update README.md ([ccd8b12](https://github.com/jackton1/django-clone/commit/ccd8b12601d1b405f63a520f39a98eb9274fd242)).
- Update README.md ([01523cb](https://github.com/jackton1/django-clone/commit/01523cb35fc8bb9c660b9894185108e0daf070e2)).
- Updated CHANGELOG.md. ([f9dac86](https://github.com/jackton1/django-clone/commit/f9dac86ed8863415d827720e6d80785aa07ec151)).
- Updated dependencies to fix test. ([1280d91](https://github.com/jackton1/django-clone/commit/1280d91f3e40d56ef3e1f24bc0caf5bf11ae7834)).
- Updated docstrings. ([85a729c](https://github.com/jackton1/django-clone/commit/85a729c51937d2e5f7b976155736af95967c63d2)).
- Updated MANIFEST.in to include model_clone templates. ([c13a70c](https://github.com/jackton1/django-clone/commit/c13a70c5c2bf48b1af58931e747a4c133dcdb24d)).
- Updated the test. ([ada0ba2](https://github.com/jackton1/django-clone/commit/ada0ba296ffe7b41137b017db505c30781cdc2ab)).
- Updated to use db. ([e489e47](https://github.com/jackton1/django-clone/commit/e489e473fce0e5585328dfd8ea3115b42d612b0f)).
- Updated to use list comprehension. ([9fa7c04](https://github.com/jackton1/django-clone/commit/9fa7c04dc7395191545a126ce0bf65619a361643)).


## [v0.1.0](https://github.com/jackton1/django-clone/releases/tag/v0.1.0) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.11...v0.1.0)) - 2019-11-23

### Misc
- "2019-11-22 21:58 - Increased django-clone version: VERSION = (0, 0, 11) to VERSION = (0, 1, 0)" ([ed56f09](https://github.com/jackton1/django-clone/commit/ed56f09fc14f0a7e49926a41ac7d288e5b38a94b)).
- Updated CHANGELOG.md. ([fc5daef](https://github.com/jackton1/django-clone/commit/fc5daef7900a32afdb39f1ffcdefb9becda2d46d)).


## [v0.0.11](https://github.com/jackton1/django-clone/releases/tag/v0.0.11) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.10...v0.0.11)) - 2019-11-23

### Fixed
- Fixed duplicate context ([be24df3](https://github.com/jackton1/django-clone/commit/be24df310abd82f4c7d716b18da82c376246578f)).
- Fixed flake8 errors. ([133d404](https://github.com/jackton1/django-clone/commit/133d404acf49bf134f382bd98e06395fde7abe1f)).
- Fixed indentation. ([18e382d](https://github.com/jackton1/django-clone/commit/18e382d9b23872a725c97ab44333e4a354d2c123)).
- Fixed lint errors. ([5b9ceae](https://github.com/jackton1/django-clone/commit/5b9ceae369da2322ee6cdbed785b0fab74275aad)).
- Fixed yaml lint errors. ([ec949cb](https://github.com/jackton1/django-clone/commit/ec949cb75bcab1783e417e19ea3c04efa86b9658)).

### Removed
- Removed empty config ([b779051](https://github.com/jackton1/django-clone/commit/b77905110a26ba96d22967cdb761e552dd0d8c6a)).
- Removed node_modules. ([ae75573](https://github.com/jackton1/django-clone/commit/ae75573519bc6223ccdbe905ed49f4c3f050da18)).
- Removed unused file. ([bc869a7](https://github.com/jackton1/django-clone/commit/bc869a78428ef27f8af0f2abdb11e56331faa4c3)).

### Misc
- "2019-11-22 21:56 - Increased django-clone version: VERSION = (0, 0, 10) to VERSION = (0, 0, 11)" ([9ba27f8](https://github.com/jackton1/django-clone/commit/9ba27f806e02ee60dadec46bcc71547953eae360)).
- Exclude the venv. ([051f0ff](https://github.com/jackton1/django-clone/commit/051f0ffe085976ff796169a807e4853b31c20800)).
- Increased test coverage and renamed clonabled -> clone. ([8f996eb](https://github.com/jackton1/django-clone/commit/8f996eb38d68cc6edd4d01ca380fd6aa18bd6e42)).
- Revert change. ([eb94c6d](https://github.com/jackton1/django-clone/commit/eb94c6d682f0e89119e36c4f019f779bfe897ce1)).
- Update README.md ([ada08a4](https://github.com/jackton1/django-clone/commit/ada08a461f6a24a3d41bd8830e73f325a3a56ae3)).
- Update README.md ([51c21ca](https://github.com/jackton1/django-clone/commit/51c21ca297b7d93f914abfd2a5cd1b360e594806)).
- Update README.md ([0eec6fa](https://github.com/jackton1/django-clone/commit/0eec6fabda05c11f890971f94d32ca4f7cdc65a0)).
- Update README.md ([a75a083](https://github.com/jackton1/django-clone/commit/a75a08363475fd523604b651556e3cfd07cbc3e8)).
- Update README.md ([d556bf6](https://github.com/jackton1/django-clone/commit/d556bf60cadca183e528e28c5448e1512499de99)).
- Update README.md ([ec89373](https://github.com/jackton1/django-clone/commit/ec893734a6b18995c19fee6c4b5395d71de2def0)).
- Update README.md inlcuded snyk tag. ([0c40147](https://github.com/jackton1/django-clone/commit/0c40147cefeb10e32d60b0f9295555760c43a84e)).
- Update the .circleci config. ([ee3d223](https://github.com/jackton1/django-clone/commit/ee3d22350e35e01b095619fba68acd143123f41f)).
- Updated .gitignore. ([707078f](https://github.com/jackton1/django-clone/commit/707078fa41b151a07ef9d10b6dce1a8e78049822)).
- Updated CHANGELOG.md. ([e2a8bf9](https://github.com/jackton1/django-clone/commit/e2a8bf9745184735d21c1bf52e8118f3d70ed9b3)).
- Updated CI and fix tox test. ([7515ef9](https://github.com/jackton1/django-clone/commit/7515ef9402c530667d32029fa9b34c541955813a)).
- Updated the .gitignore. ([4ce930b](https://github.com/jackton1/django-clone/commit/4ce930bbb09f5ef7363807726fbed71d7bc63f32)).
- Updated the config ([d9fa0d4](https://github.com/jackton1/django-clone/commit/d9fa0d4951530420dde68a55ea392190ba7a71f7)).
- Updated the context. ([9b6c7ca](https://github.com/jackton1/django-clone/commit/9b6c7caa490b512ba9f9f8c644d57e26a3273f1b)).
- Updated the README.md ([ad2ec62](https://github.com/jackton1/django-clone/commit/ad2ec623f86a2ba585068d8ee46a5d577ab9e866)).
- Updated the README.md ([dfce131](https://github.com/jackton1/django-clone/commit/dfce131a02c947b2d67c97bcab56b7831ebfe6c0)).
- Updated the test. ([bed71a0](https://github.com/jackton1/django-clone/commit/bed71a010637a5310108a4997073e33fd02b339d)).
- Updated the test. ([c3840b0](https://github.com/jackton1/django-clone/commit/c3840b04fd290c57a5a4d2135b06e8349baa8a16)).
- updated the tox.ini ([f74dd67](https://github.com/jackton1/django-clone/commit/f74dd67de8c6b7f5d2e66d3f23bc43bfaff4b95a)).
- Updated to include excluded fields. ([76ead4d](https://github.com/jackton1/django-clone/commit/76ead4d5a6fc3c0e7e8fcb754a1dbf314700e147)).
- Updated to output xml test report. ([2e65ca3](https://github.com/jackton1/django-clone/commit/2e65ca3ddec21ca7d2f2f997e6545404955b79d7)).
- Updated tox config. ([e62c65c](https://github.com/jackton1/django-clone/commit/e62c65c9443c9d8dc47bff773ecf1a76b21ab669)).


## [v0.0.10](https://github.com/jackton1/django-clone/releases/tag/v0.0.10) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.9...v0.0.10)) - 2019-11-12

### Fixed
- Fixed manage.py. ([eaa73f6](https://github.com/jackton1/django-clone/commit/eaa73f6687b4bf586cd4c6468819a615aea76d37)).
- Fixed pyenv. ([66aabd5](https://github.com/jackton1/django-clone/commit/66aabd5536d6b924d56b4a04180c460fdc399449)).
- Fixed pyenv. ([ad03e08](https://github.com/jackton1/django-clone/commit/ad03e083ba36863af88819d90a4b28dd215b55c7)).
- Fixed pyenv. ([88b67f1](https://github.com/jackton1/django-clone/commit/88b67f13e8e3259f068c7577511ffcdd54a0c195)).
- Fixed pyenv. ([b265eba](https://github.com/jackton1/django-clone/commit/b265ebae44e6f1904594dc80f66f794e5aafb4d3)).
- Fixed python27. ([20b3c55](https://github.com/jackton1/django-clone/commit/20b3c55ecaa376d8069134427b39ce857c218931)).
- Fixed tox. ([82afdde](https://github.com/jackton1/django-clone/commit/82afdde7929d85b55bec6e4ad8784e268564bbee)).

### Removed
- Removed bumpversion==0.5.3. ([60a18e5](https://github.com/jackton1/django-clone/commit/60a18e57e7e4b98335cc7c612c25e77f8a5b4564)).

### Misc
- "2019-11-12 06:32 - Increased django-clone version: VERSION = (0, 0, 9) to VERSION = (0, 0, 10)" ([444b53f](https://github.com/jackton1/django-clone/commit/444b53fce9c4b8c7ca757104960342255711eb9a)).
- Updated .circleci config. ([35f8480](https://github.com/jackton1/django-clone/commit/35f8480564d8a4b4bef7400795520479f8d91818)).
- Updated .circleci config. ([af79831](https://github.com/jackton1/django-clone/commit/af798313389e196a0a5d59e2ec63141ff86d9383)).
- Updated .circleci config. ([4ebf82f](https://github.com/jackton1/django-clone/commit/4ebf82f460d14b5417b25d0bbd8e444599deeb34)).
- Updated .circleci config. ([f261c02](https://github.com/jackton1/django-clone/commit/f261c021c542b2544edad6f31512f16d7ab86283)).
- Updated .circleci config. ([b247dd3](https://github.com/jackton1/django-clone/commit/b247dd32d14d8e9bc911db28f223937c990da8ca)).
- Updated .circleci config. ([524e664](https://github.com/jackton1/django-clone/commit/524e664bcb1c907a6607cfb78f59aecbe9437d1b)).
- Updated .circleci config. ([07d6665](https://github.com/jackton1/django-clone/commit/07d66650dc8381565eda9a841c068ae5ce18059c)).
- Updated .circleci config. ([93be99e](https://github.com/jackton1/django-clone/commit/93be99ea92e73d0c2baf9c43a188deb187f599da)).
- Updated .circleci config. ([745d253](https://github.com/jackton1/django-clone/commit/745d253282dfcdd3849926af934dd90a84c2df29)).
- Updated .circleci config. ([d9cbdb8](https://github.com/jackton1/django-clone/commit/d9cbdb8d7173303c84a92339f51603711c6f3f23)).
- Updated .circleci config. ([35c75ff](https://github.com/jackton1/django-clone/commit/35c75ff3df71a00984a84058e6239a6167e0e442)).
- Updated .circleci config. ([3c7b10c](https://github.com/jackton1/django-clone/commit/3c7b10cd99ba73f898809656f34396c8a649b998)).
- Updated .circleci config. ([93b9f0a](https://github.com/jackton1/django-clone/commit/93b9f0aaa3364e995b0f344883413679efa8dd02)).
- Updated .circleci config. ([d6f7899](https://github.com/jackton1/django-clone/commit/d6f7899ccf17baab2f7c6b4d552354d2bf546c60)).
- Updated .circleci config. ([0ac7ad8](https://github.com/jackton1/django-clone/commit/0ac7ad849f082555d79593f0e693a6e9cb8d6c2a)).
- Updated .circleci config. ([e4a51c1](https://github.com/jackton1/django-clone/commit/e4a51c164783d770f1cb1f7cc23528234b63e37d)).
- Updated .circleci config. ([5076819](https://github.com/jackton1/django-clone/commit/50768196198a6009fa23cb99ca9e002ce26a8dde)).
- Updated .circleci config. ([e5e5c7e](https://github.com/jackton1/django-clone/commit/e5e5c7e8608e4e2706f09d99dbc5eaefb0ce6154)).
- Updated .circleci config. ([642c236](https://github.com/jackton1/django-clone/commit/642c23698c4a90eb6cd882ae055f058628ec94c3)).
- Updated .circleci config. ([fcef3b4](https://github.com/jackton1/django-clone/commit/fcef3b4985e229b4af70744816aa1514c3a1f0b3)).
- Updated .circleci config. ([bc7cc2c](https://github.com/jackton1/django-clone/commit/bc7cc2c7818e39070c3b5f06e114fc8ca5382343)).
- Updated .circleci config. ([97cba25](https://github.com/jackton1/django-clone/commit/97cba252f03bdca0157f5f437607787b7084dff5)).
- Updated CHANGELOG.md. ([74ad767](https://github.com/jackton1/django-clone/commit/74ad767ea9addc9a9e94e4d7bbb59f4deef32847)).
- Updated MANIFEST.in ([0d39096](https://github.com/jackton1/django-clone/commit/0d390966488978453da3b3fc3026eacf2c620686)).


## [v0.0.9](https://github.com/jackton1/django-clone/releases/tag/v0.0.9) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.8...v0.0.9)) - 2019-11-10

### Misc
- "2019-11-10 14:52 - Increased django-clone version: VERSION = (0, 0, 8) to VERSION = (0, 0, 9)" ([5b3dbb0](https://github.com/jackton1/django-clone/commit/5b3dbb0ed3a3f39103a7e7991c8a4681a99c856b)).
- Downgraded twine ([7f954b1](https://github.com/jackton1/django-clone/commit/7f954b1abcc9cc62e4200267bdad7fc1c8f9c65f)).
- Updated CHANGELOG.md. ([5a3a495](https://github.com/jackton1/django-clone/commit/5a3a495306d020444ee13abdb3c96986e8204072)).


## [v0.0.8](https://github.com/jackton1/django-clone/releases/tag/v0.0.8) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.7...v0.0.8)) - 2019-11-10

### Misc
- "2019-11-10 14:49 - Increased django-clone version: VERSION = (0, 0, 7) to VERSION = (0, 0, 8)" ([453bef2](https://github.com/jackton1/django-clone/commit/453bef2a3b35707ad4c0d0644cc150f137a8f72c)).
- Updated CHANGELOG.md. ([908e983](https://github.com/jackton1/django-clone/commit/908e983c924e517d1f6679162656a855f3f783cc)).
- Updated the MANIFEST.in ([b5c3558](https://github.com/jackton1/django-clone/commit/b5c3558d0711a1c200610a0791ae74b13bb92557)).


## [v0.0.7](https://github.com/jackton1/django-clone/releases/tag/v0.0.7) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.6...v0.0.7)) - 2019-11-10

### Misc
- "2019-11-10 14:30 - Increased django-clone version: VERSION = (0, 0, 6) to VERSION = (0, 0, 7)" ([e1cd9e7](https://github.com/jackton1/django-clone/commit/e1cd9e7b29b1d8d9539fa09b2e97ee8f44e7a76e)).
- Pinned twine at 1.4.0. ([c96daa8](https://github.com/jackton1/django-clone/commit/c96daa806954507eecea9c65bd859f155636439d)).
- Updated CHANGELOG.md. ([c485f4d](https://github.com/jackton1/django-clone/commit/c485f4d3923b0712a7346da453c9eeb495b9a762)).


## [v0.0.6](https://github.com/jackton1/django-clone/releases/tag/v0.0.6) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.5...v0.0.6)) - 2019-11-10

### Added
- Added twine to deploy requirements ([59eba81](https://github.com/jackton1/django-clone/commit/59eba81e23cfb07687ae2c1b01ce82573597f61a)).

### Misc
- "2019-11-10 14:29 - Increased django-clone version: VERSION = (0, 0, 5) to VERSION = (0, 0, 6)" ([93288ef](https://github.com/jackton1/django-clone/commit/93288efb47106d342f169f5fa797723aa1adc802)).
- Updated CHANGELOG.md. ([3a170ea](https://github.com/jackton1/django-clone/commit/3a170eaf3c242f52862efaa1a68310041c6765ee)).


## [v0.0.5](https://github.com/jackton1/django-clone/releases/tag/v0.0.5) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.3...v0.0.5)) - 2019-11-10

### Added
- Added the CHANGELOG.md ([3e6aeb2](https://github.com/jackton1/django-clone/commit/3e6aeb2307fe5a29b9e68fd1acac1ae5e3cfe974)).

### Misc
- "2019-11-10 14:24 - Increased django-clone version: VERSION = (0, 0, 3) to VERSION = (0, 0, 4)" ([64a350e](https://github.com/jackton1/django-clone/commit/64a350ec52af442464825384031a1e690c31e297)).
- "2019-11-10 14:26 - Increased django-clone version: VERSION = (0, 0, 4) to VERSION = (0, 0, 5)" ([6ba3b55](https://github.com/jackton1/django-clone/commit/6ba3b55185b450b5c7f1eec6a38e65447b237172)).
- Updated CHANGELOG.md. ([c5a00da](https://github.com/jackton1/django-clone/commit/c5a00daa5fc4b269616a5a82409bcfc63f493536)).
- Updated the release-to-pypi command. ([13a954c](https://github.com/jackton1/django-clone/commit/13a954c03c94051fdf32cd7302b204e596f097a1)).


## [v0.0.3](https://github.com/jackton1/django-clone/releases/tag/v0.0.3) ([compare](https://github.com/jackton1/django-clone/compare/v0.0.1...v0.0.3)) - 2019-11-10

### Added
- Add class variable USE_UNIQUE_DUPLICATE_SUFFIX ([fd207c4](https://github.com/jackton1/django-clone/commit/fd207c41398a469ebca01bbe7ad7c0284a54d218)).
- Add django-admin ClonableModelAdmin ([147c56f](https://github.com/jackton1/django-clone/commit/147c56fa59f770278050eeecf0868a611a15e060)).
- Added create_copy_of_instance utility. ([ab41b02](https://github.com/jackton1/django-clone/commit/ab41b02f1b52cf8f4ca6b7452085f66e69f25bb7)).
- Added new line at the end of the file. ([b5b68fc](https://github.com/jackton1/django-clone/commit/b5b68fc139e5c708c5f370fc4b3256d31d1daefc)).
- Added new line. ([4327dab](https://github.com/jackton1/django-clone/commit/4327dab28b06a0efec071eb4822bc916945399dc)).

### Changed
- Change comparison to check for any truthy value ([6d11bd1](https://github.com/jackton1/django-clone/commit/6d11bd1ae43d395ec08e6764cdf7cff597b79f54)).
- Changed docker image. ([9644e73](https://github.com/jackton1/django-clone/commit/9644e73e4682904df818e678484971edb5118990)).
- Changed docker image. ([d2881b9](https://github.com/jackton1/django-clone/commit/d2881b926da2a372114a64a2ef1bf1934021f184)).

### Documented
- docs: create .all-contributorsrc ([ccef5aa](https://github.com/jackton1/django-clone/commit/ccef5aa2936f2fbc5f977d60fb756ec97449ad01)).
- docs: update .all-contributorsrc ([ad949d4](https://github.com/jackton1/django-clone/commit/ad949d4d2966a5d19a2164be5b2b0a9dc2ba4f3d)).
- docs: update .all-contributorsrc ([f38e062](https://github.com/jackton1/django-clone/commit/f38e06215514a92eea514cd1ec2d37d1db5283ad)).
- docs: update README.md ([93559df](https://github.com/jackton1/django-clone/commit/93559df51dcd4b1fb53b78c332a5fa823c5650ac)).
- docs: update README.md ([a6f62ee](https://github.com/jackton1/django-clone/commit/a6f62ee5da231ec20849b29c983775edf6810e38)).
- docs: update README.md ([e0fc6a6](https://github.com/jackton1/django-clone/commit/e0fc6a6ab15a1ae05f034353da65b3870d4d4af1)).

### Fixed
- Fix admin url regex ([e806e97](https://github.com/jackton1/django-clone/commit/e806e97bcbaec9f3030db97f6afce4ff9700619e)).
- Fix clone of one to many and many to one ([78a506b](https://github.com/jackton1/django-clone/commit/78a506b6caff3a7715f35a617f96c56bf2087028)).
- Fixed install command. ([1ea325c](https://github.com/jackton1/django-clone/commit/1ea325c2981a22f62b2c52011a3c77d82c2c77c5)).
- Fixed install command. ([5e648ae](https://github.com/jackton1/django-clone/commit/5e648ae111f662346573a4e6b107d791e7da6456)).
- Fixed test. ([d7cc014](https://github.com/jackton1/django-clone/commit/d7cc014c7b7547863865bdb98b1e8c7d2b32d75d)).
- Fixed test. ([9a8a12a](https://github.com/jackton1/django-clone/commit/9a8a12a352bab1861222fea7506a526eb39c2b49)).
- Fixed test. ([1ac7441](https://github.com/jackton1/django-clone/commit/1ac744136acdffd2c32be69d16c7b794565505cb)).
- Fixed virtualenv. ([eab8da9](https://github.com/jackton1/django-clone/commit/eab8da905bd110e7d8bffe4b1bb680c45caa8d75)).

### Removed
- Remove redundant one to one clone. ([d1a56bd](https://github.com/jackton1/django-clone/commit/d1a56bdc1c7f000b5729b7c13324077e1b2a7267)).
- Removed extra spaces. ([28f327f](https://github.com/jackton1/django-clone/commit/28f327fbdf129e5477dc200f8af822a10a4867a0)).
- Removed unused code. ([6216032](https://github.com/jackton1/django-clone/commit/6216032d67534f0ab35da8efb574a6c1aebcf838)).

### Misc
- "2019-11-10 14:18 - Increased django-clone version: VERSION = (0, 0, 1) to VERSION = (0, 0, 2)" ([f171448](https://github.com/jackton1/django-clone/commit/f171448985114ef4808a29a0a5fa708e62d52c75)).
- "2019-11-10 14:20 - Increased django-clone version: VERSION = (0, 0, 2) to VERSION = (0, 0, 3)" ([ace4fba](https://github.com/jackton1/django-clone/commit/ace4fbab179c2243c51f01aa60ef41e7fe6fedfc)).
- filter pk field from concrete_fields ([76501cc](https://github.com/jackton1/django-clone/commit/76501cca743666435b0b8f12626d6251173889c2)).
- Switched to bash. ([c4b542d](https://github.com/jackton1/django-clone/commit/c4b542ddb52bb5b6ceb88d64e2c596dda31e1b2c)).
- Switched to source. ([9e7eb16](https://github.com/jackton1/django-clone/commit/9e7eb16001d42f47afc276fcd61c31643604bc8a)).
- Update config. ([057fc88](https://github.com/jackton1/django-clone/commit/057fc88a3c245a7df85cab812a284b78411e41a6)).
- Update config. ([d988c0c](https://github.com/jackton1/django-clone/commit/d988c0ca2801eca4fd4a870fbc0376244a9b7326)).
- Update config. ([dd9baee](https://github.com/jackton1/django-clone/commit/dd9baeedd62c7be05118e947545c157fcf5255a9)).
- Update config. ([6fe6cb2](https://github.com/jackton1/django-clone/commit/6fe6cb2afc81573c7b4e486d31a3fc1d1dcee148)).
- Update config. ([ad5ba6a](https://github.com/jackton1/django-clone/commit/ad5ba6af2dbf692c3dcbaf32f4d35162ad03fdd1)).
- Update config. ([051da38](https://github.com/jackton1/django-clone/commit/051da3893b920ae59a041e7e8b9c918e30c3264a)).
- Update config. ([53d0c31](https://github.com/jackton1/django-clone/commit/53d0c313479437c69247d17f93a7961cba19b6f3)).
- Update config. ([9d2b3d4](https://github.com/jackton1/django-clone/commit/9d2b3d4d5b8aba7011bf87894fea33766852a4e3)).
- Update config. ([5cd88ec](https://github.com/jackton1/django-clone/commit/5cd88ece534251311c8852e3ea74e707b9a545c2)).
- Update issue templates ([f091df1](https://github.com/jackton1/django-clone/commit/f091df187c41a71a87f3fd8b79bbdd2fa554762c)).
- Update README.md ([9fa0984](https://github.com/jackton1/django-clone/commit/9fa09846b1fefe3022068acdea96ef638783c5f6)).
- Update README.md ([aefddaf](https://github.com/jackton1/django-clone/commit/aefddaf88baed3e3d0a99c28ca71bbd6a82ef6cb)).
- Update README.md ([07a4ad6](https://github.com/jackton1/django-clone/commit/07a4ad635d6b7fcf51c097d8fe1eb960e4e71bc0)).
- Update README.md ([91cf082](https://github.com/jackton1/django-clone/commit/91cf08265bc75d956c2ba24a41e580ba3c40d8ab)).
- Update README.md ([b086098](https://github.com/jackton1/django-clone/commit/b086098b89f6946b233c51e3e8caa69bae6842a0)).
- Update README.md ([b6c7b99](https://github.com/jackton1/django-clone/commit/b6c7b99a0238c34d055ac4140dcb940f261f685c)).
- Update README.md ([aae2730](https://github.com/jackton1/django-clone/commit/aae2730512a9afaf0ee4acf937e342f7ccab0e5c)).
- Update README.md ([90e26b9](https://github.com/jackton1/django-clone/commit/90e26b97b805cb2742d6b8b055e9fe9b0123ed98)).
- Update README.md ([b17545f](https://github.com/jackton1/django-clone/commit/b17545fbd89405e844960bc05b43554bbba175e5)).
- Update README.md ([27f9409](https://github.com/jackton1/django-clone/commit/27f94095b7a4d2fd8bf81c5ff9dd75668f279e66)).
- Update README.md ([4448e3b](https://github.com/jackton1/django-clone/commit/4448e3b3d0b814f42e91d929d80b67619255ba81)).
- Update README.md ([86489d5](https://github.com/jackton1/django-clone/commit/86489d5dbbc43b3d556546cd8cb5566487de7f95)).
- Update README.md ([ca34a7b](https://github.com/jackton1/django-clone/commit/ca34a7ba6f4936c06958c6c2ad25fef3d4f56809)).
- Update README.md ([66de17b](https://github.com/jackton1/django-clone/commit/66de17bee73f97c8312bd7732aec3181c4165dd7)).
- Update README.md ([d75d497](https://github.com/jackton1/django-clone/commit/d75d4970083a86c68fa1fef20869dfde2cfe2414)).
- Update README.md ([958ba4d](https://github.com/jackton1/django-clone/commit/958ba4d7808e63723984c5e2e3b45a2982b1fcbc)).
- Update README.md ([13f6409](https://github.com/jackton1/django-clone/commit/13f64090d88987477a3692532082c40cc4d8d08b)).
- Update README.md ([0e4297e](https://github.com/jackton1/django-clone/commit/0e4297e956db20d89c672f97ed412fc707ea65a5)).
- Update README.md ([92876d2](https://github.com/jackton1/django-clone/commit/92876d2d0045c3cd19f3579bb3b21144aadc9426)).
- Update README.md ([9ed3f86](https://github.com/jackton1/django-clone/commit/9ed3f860ecfb78a6dbd172a8569f93574b8496c0)).
- Update README.md ([c00a867](https://github.com/jackton1/django-clone/commit/c00a8670621ab9d1bbbfcd3c7867423966aef867)).
- Update README.md ([4a5b447](https://github.com/jackton1/django-clone/commit/4a5b447b872a036b42f45c5e15f51a476162eda2)).
- Update README.md ([d1a05e5](https://github.com/jackton1/django-clone/commit/d1a05e58fc67ae33809edd388cb28561bd2d8f7b)).
- Update README.md ([8e170f5](https://github.com/jackton1/django-clone/commit/8e170f5361a413cd3d18bafdba5584011807af57)).
- Update README.md ([fbdb736](https://github.com/jackton1/django-clone/commit/fbdb7361ed0797d024c1aa730b73e5c2d7beefc3)).
- Update tox config. ([a165f6e](https://github.com/jackton1/django-clone/commit/a165f6ee67022c63636b997e6533f15487cfc58a)).
- Update tox config. ([97ad522](https://github.com/jackton1/django-clone/commit/97ad5228cf467696989f300b28bd55386012e225)).
- Updated circle ci config and readme.md ([69e4626](https://github.com/jackton1/django-clone/commit/69e4626af5ada307d4272a6ccbcdf27a9676047c)).
- Updated circle ci config. ([edcfb74](https://github.com/jackton1/django-clone/commit/edcfb744e0a24f7f65b2e669b831176cb8a3e2f6)).
- Updated circle ci config. ([22f85da](https://github.com/jackton1/django-clone/commit/22f85dacac13e7243083027ac63128cb5422f82e)).
- Updated circle ci config. ([079a40c](https://github.com/jackton1/django-clone/commit/079a40c4c97faa2c0b7ece59f3b2e50ef83c1824)).
- Updated circle ci config. ([9a69e2a](https://github.com/jackton1/django-clone/commit/9a69e2a1b0e3b0146678941780b3e8d395df827e)).
- Updated circle ci config. ([cf2bf5d](https://github.com/jackton1/django-clone/commit/cf2bf5d028dfa54177160ecf6c1b797cd82a8048)).
- Updated circle ci config. ([f90d00a](https://github.com/jackton1/django-clone/commit/f90d00a55a82b7cacb13d907ac6da52ea7136508)).
- Updated config. ([679ab64](https://github.com/jackton1/django-clone/commit/679ab64409d000c5892da9f945e6aebe00332148)).
- Updated example ([4e03976](https://github.com/jackton1/django-clone/commit/4e0397693d6cb6345d1a1620e3f25f0c4024c9a3)).
- Updated install command ([babd02e](https://github.com/jackton1/django-clone/commit/babd02e4ee52b892c208657266fb1c440ecf5608)).
- Updated install command ([ed43314](https://github.com/jackton1/django-clone/commit/ed43314c94d4a903d71828ce48e7d0dd9505d5c8)).
- Updated install command ([4f502b7](https://github.com/jackton1/django-clone/commit/4f502b72b435ae03252f9990f18174e75af1c8af)).
- Updated install command ([365dc2d](https://github.com/jackton1/django-clone/commit/365dc2d23d77c328464a7591aa379ad35bb626d8)).
- Updated the ClonableModelAdmin to support duplicate actions and moved the submit row to using an object tool link. ([164bc35](https://github.com/jackton1/django-clone/commit/164bc356c696d836ee2b0a14654da8e882692dea)).
- Updated the deploy requirement. ([cb44d84](https://github.com/jackton1/django-clone/commit/cb44d84a70a0f1ff216bb0201c7a1344b3675894)).
- Updated the install command. ([739445c](https://github.com/jackton1/django-clone/commit/739445c7e5c020532a8fdcea59dd727396a04b71)).
- Updated the python config. ([e20fd58](https://github.com/jackton1/django-clone/commit/e20fd580f47aa064b70a810516959fedc01ff8f1)).
- Updated the README.md ([f4ea4c6](https://github.com/jackton1/django-clone/commit/f4ea4c62b5fbe75031aa015fc138dcea60275d4b)).
- Updated the README.md ([514381e](https://github.com/jackton1/django-clone/commit/514381e082c1730476c6ca7f64f8999d793e60be)).
- Updated the README.md. ([2e8d2d8](https://github.com/jackton1/django-clone/commit/2e8d2d88fd16969d2e7b6471902d669e0149fd7c)).
- Updated the README.md. ([bbce294](https://github.com/jackton1/django-clone/commit/bbce2943f3d1b478e445527a5b4b84479bd97681)).
- Updated user. ([2178b65](https://github.com/jackton1/django-clone/commit/2178b650d4508177330d69f547634c60e6c68f42)).
- use field.primary_key to check for custom pk ([4f24a07](https://github.com/jackton1/django-clone/commit/4f24a07e93f32e1627d68bc4285311b6145d9e2e)).


## [v0.0.1](https://github.com/jackton1/django-clone/releases/tag/v0.0.1) ([compare](https://github.com/jackton1/django-clone/compare/7b01ca1df72d4ac2a691257807cf9eab426332ae...v0.0.1)) - 2019-04-06

### Added
- Added base class setup. ([7b01ca1](https://github.com/jackton1/django-clone/commit/7b01ca1df72d4ac2a691257807cf9eab426332ae)).
- Added circleci config. ([af22fc8](https://github.com/jackton1/django-clone/commit/af22fc8c00fdb17f12d83140c35a50cd8c678ba9)).
- Added pypi deployment setup. ([96816e6](https://github.com/jackton1/django-clone/commit/96816e66ca00d6146860cb96e64047d8f5add6d8)).

### Fixed
- Fixed typo. ([1cfe037](https://github.com/jackton1/django-clone/commit/1cfe037e50c8fca6c31a31ecf4b36b7c88c39fbe)).

### Misc
- "2019-04-06 18:21 - Increased django-clone version: VERSION = (0, 0, 0) to VERSION = (0, 0, 1)" ([4b16bc3](https://github.com/jackton1/django-clone/commit/4b16bc3025acdd44b6903e31b78ad8621fe6f797)).
- Create LICENSE ([c29d4cb](https://github.com/jackton1/django-clone/commit/c29d4cb7d9f68bb83a14be385db10a7cc4be5a7d)).
- Initial commit. ([155123a](https://github.com/jackton1/django-clone/commit/155123a576ffc0653fa03900ef5b91e06668c278)).
- Renamed django_model_clone -> django_clone ([ca05bff](https://github.com/jackton1/django-clone/commit/ca05bff9adde29ac43ec275f16025c3e92a9fead)).
- Simplified logic. ([f1cd3e1](https://github.com/jackton1/django-clone/commit/f1cd3e1a205ce57f8b89e987044659bc14227238)).
- Simplify README. ([72db785](https://github.com/jackton1/django-clone/commit/72db785e26ed662ef8bd3e634a77a07cc080b86a)).
- Tested the clone mixin. ([1dc308a](https://github.com/jackton1/django-clone/commit/1dc308ae934440b902e245f4d9f869e8ed841972)).
- Testing triggered builds. ([a7a1108](https://github.com/jackton1/django-clone/commit/a7a1108f3d75c1ef7de56e43c208e3e262ef71e1)).
- Update clone.py ([9107bdd](https://github.com/jackton1/django-clone/commit/9107bdd1f1f8e1beea7cc5678944b22c48bef817)).
- Update README.md ([4b6233a](https://github.com/jackton1/django-clone/commit/4b6233a0a7d57ef948d56e9660374047f9e8e34f)).
- Update README.md ([db6bd52](https://github.com/jackton1/django-clone/commit/db6bd520edea8e12f4385fe3a2e5124109fbe4d7)).
- Update README.md ([a25d7df](https://github.com/jackton1/django-clone/commit/a25d7df07f243ca194307670c063c7ebcb0422c5)).
- Update README.md ([6b77c08](https://github.com/jackton1/django-clone/commit/6b77c087948634c2366bd371986ad754cb3f7966)).
- Update README.md ([81003f1](https://github.com/jackton1/django-clone/commit/81003f105ff75e30240bc40473bd2ceb0cc4f72c)).
- Updated mixin. ([bce8438](https://github.com/jackton1/django-clone/commit/bce8438a007e1c1aa99e24dcde805842534d3439)).
- Updated the field instance comparison. ([ed527a8](https://github.com/jackton1/django-clone/commit/ed527a8ab2142f31b365a59dc75f0d772fa38023)).
- Updated the README. ([b11c106](https://github.com/jackton1/django-clone/commit/b11c106488ed29b5328ad3ca5948617709ceb9b1)).


